package org.anc.tool.ui;

import java.util.*;
import java.lang.annotation.Annotation;
import java.lang.reflect.Field;

import org.anc.tool.annotation.*;
import org.anc.tool.api.IProcessor;
import org.anc.tool.ui.swing.Panel;
import org.slf4j.*;

public abstract class AbstractUIFactory implements IUserInterfaceFactory
{
   private static final Logger logger = LoggerFactory.getLogger(AbstractUIFactory.class);
   public UserInterface create(Class<? extends IProcessor> procClass)
   {
      logger.debug("Creating user interface for {}", procClass.getName());
      Panel panel = createPanel();
      ProcessorFactory factory = new ProcessorFactory(procClass);
      
      Processor procAnnotation = procClass.getAnnotation(Processor.class);
      String tabTitle = procAnnotation.value();
      
      UserInterface ui = new UserInterface(tabTitle, panel, factory);
      
      Field[] fields = procClass.getDeclaredFields();
      for (Field field : fields)
      {
         Annotation[] annotations = field.getAnnotations();
         for (Annotation a : annotations)
         {
            Class<? extends Annotation> type = a.annotationType();
            if (type == ChoiceProperty.class)
            {
               IComponent choice = createChoice((ChoiceProperty)a);
               addToPanel(panel, choice);
               factory.add(field, choice);
            }
            else if (type == ExclusiveListProperty.class)
            {
               IComponent list = createExclusiveList((ExclusiveListProperty)a);
               addToPanel(panel, list);
               factory.add(field, list);
            }
            else if (type == ListProperty.class)
            {
               IComponent list = createList((ListProperty)a);
               addToPanel(panel, list);
               factory.add(field, list);
            }
            else if (type == StringProperty.class)
            {
               IComponent string = createTextField((StringProperty)a);
               addToPanel(panel, string);
               factory.add(field, string);
            }
            else if (type == TokenProperty.class)
            {
               IComponent token = createTokenField((TokenProperty) a);
               addToPanel(panel, token);
               factory.add(field, token);
            }
         }
      }
      return ui;
   }

}
