package org.anc.tool.ui;

import java.lang.reflect.Field;
import java.util.*;

import org.anc.tool.api.IProcessor;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ProcessorFactory
{
   private Class<? extends IProcessor> theClass;
   private Map<String, IComponent> initializers = new HashMap<String, IComponent>();
   private static Logger logger = LoggerFactory
         .getLogger(ProcessorFactory.class);

   public ProcessorFactory(Class<? extends IProcessor> procClass)
   {
      theClass = procClass;
   }

   public void add(Field field, IComponent component)
   {
      logger.debug("{} will be initialized by {}", field.getName(), component.getClass().getName());
      initializers.put(field.getName(), component);
   }

   public IProcessor create() throws InstantiationException,
         IllegalAccessException
   {
      logger.debug("Creating processor: {}", theClass.getName());
      
      IProcessor proc = (IProcessor) theClass.newInstance();
      for (Field field : theClass.getDeclaredFields())
      {
         IComponent component = initializers.get(field.getName());
         if (component != null)
         {
            logger.debug("Initializing field {}: {}", field.getName(), component.getValue().getClass().getName());
            // Allows us to set private and protected fields.
            field.setAccessible(true);
            field.set(proc, component.getValue());
         }
      }
      return proc;
   }
}
