package org.anc.tool.ui.swing;

import java.util.LinkedList;

import org.anc.conf.AnnotationConfig;
import org.anc.conf.AnnotationType;
import org.anc.tool.ui.i18n.Messages;
import org.anc.tool.ui.IComponent;
import org.anc.ui.GBC;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


public class AnnotationPanel extends Panel implements IComponent
{
   private static final long serialVersionUID = 1L;
   private static final Logger logger = LoggerFactory.getLogger(AnnotationPanel.class);
   
   protected java.util.List<AnnotationCheckBox> boxes = new LinkedList<AnnotationCheckBox>();
   
   public AnnotationPanel(String title)
   {
      super(title);
   }
   
   public AnnotationPanel(String title, String[] types)
   {
      this(title, types, -1);
   }
   
   public AnnotationPanel(String title, String[] types, int selected)
   {
      super(title);
      logger.debug(Messages.log.CREATING_ANNOTATION_PANEL, title);
      GBC gbc = new GBC();
      gbc.fillHorizontal();
      gbc.anchorLeft();
      int count = 0;
      for (String typeName : types)
      {
         logger.debug(Messages.log.ADDING_ANNOTATION_TYPE, typeName);
         AnnotationType type = AnnotationType.getValueOf(typeName);
         if (type != null)
         {
            AnnotationCheckBox box = add(type, gbc);
            if (count == selected)
            {
               box.setSelected(true);
            }
            gbc.down();
            ++count;
         }
      }
   }

   public Object getValue()
   {
      AnnotationConfig result = new AnnotationConfig();
      for (AnnotationCheckBox box : boxes)
      {
         if (box.isSelected())
         {
            result.add(box.getValue());
         }
      }
      return result;
   }
   
   protected AnnotationCheckBox add(AnnotationType type, GBC gbc)
   {
      AnnotationCheckBox box = new AnnotationCheckBox(type);
      this.add(box, gbc);
      boxes.add(box);
      return box;
   }
   
}
