package org.anc.tool.ui.swing;

import java.awt.Component;

import javax.swing.JPanel;

import org.anc.conf.AnnotationConfig;
import org.anc.tool.annotation.ChoiceProperty;
import org.anc.tool.annotation.ExclusiveListProperty;
import org.anc.tool.annotation.ListProperty;
import org.anc.tool.annotation.StringProperty;
import org.anc.tool.annotation.TokenProperty;
import org.anc.tool.ui.AbstractUIFactory;
import org.anc.tool.ui.IComponent;
import org.anc.tool.ui.i18n.Messages;
import org.anc.ui.GBC;

import org.slf4j.*;

public class SwingFactory extends AbstractUIFactory
{
   private static final Logger logger = LoggerFactory.getLogger(SwingFactory.class);
   
   private AnnotationConfig config;
   private GBC gbc;
   
   public SwingFactory(AnnotationConfig config)
   {
      this.config = config;
      gbc = new GBC();
      gbc.fillHorizontal();
      gbc.insets(2,5,2,5);
   }
   
   public Panel createPanel()
   {
      logger.debug(Messages.log.CREATING_UNNAMED_PANEL);
      return new Panel();
   }
   
   public Panel createPanel(String title)
   {      
      logger.debug(Messages.log.CREATING_NAMED_PANEL, title);
      return new Panel(title);
   }

   public void addToPanel(Panel panel, IComponent component)
   {
      panel.add((Component)component, gbc);
      gbc.down();
   }

   public IComponent createChoice(ChoiceProperty property)
   {
      logger.debug(Messages.log.CREATING_CHOICE_PANEL, property.name());
      return new ChoicePanel(property.name(), property.choices(), property.selected());
   }

   public IComponent createExclusiveList(ExclusiveListProperty list)
   {
      logger.debug(Messages.log.CREATING_EX_LIST_PANEL, list.name());
      return new ExclusiveListPanel(list.name(), list.types(), list.selected());
   }

   public IComponent createList(ListProperty list)
   {
      logger.debug(Messages.log.CREATING_ANNOTATION_PANEL, list.name());
      return new AnnotationPanel(list.name(), list.types());
   }

   public IComponent createTextField(StringProperty string)
   {
      logger.debug(Messages.log.CREATING_TEXT_FIELD, string.value());
      return new TextField(string.value());
   }

   public IComponent createTokenField(TokenProperty token)
   {
      logger.debug(Messages.log.CREATING_TOKENIZATION_PANEL);
      return new PartOfSpeechPanel(config, token.selected());
   }

}
